# FLUTTER NEARBY MESSAGES API

[Google Nearby Messages API](https://developers.google.com/nearby/messages/overview) for Flutter

## Installation
First, add `flutter_nearby_messages_api` as a [dependency in your pubspec.yaml file](https://flutter.io/platform-plugins/).

## iOS
Get and add a google cloud nearby messages API key to your project [https://developers.google.com/nearby/messages/ios/get-started](https://developers.google.com/nearby/messages/android/get-started)

```Swift
nearbyMessagesApi.setAPIKey('API_KEY');
```

## Android
Get and add a google cloud nearby messages API key to your project [https://developers.google.com/nearby/messages/android/get-started](https://developers.google.com/nearby/messages/android/get-started)


```xml
<manifest xmlns:android="http://schemas.android.com/apk/res/android"
    package="com.google.sample.app" >
    <application ...>
        <meta-data
            android:name="com.google.android.nearby.messages.API_KEY"
            android:value="API_KEY" />
        <activity>
        ...
        </activity>
    </application>
</manifest>
```

## Example
```dart
import 'package:flutter_nearby_messages_api/flutter_nearby_messages_api.dart';

class main {
    /**
    * This method gets the message when an a nearby device sends one
    */
    static void onFound(dynamic arguments) {
      print(arguments);
    }
    
    /**
    * This method gets the message when a nearby device leaves
    */
    static void onLost(dynamic arguments) {
      print(arguments);
    }

    // init NearbyMessagesApi
    FlutterNearbyMessagesApi nearbyMessagesApi = FlutterNearbyMessagesApi(onFound, onLost);
 
    Future<void> main() async {
      // config for iOS
      await nearbyMessagesApi.setAPIKey('API_KEY');
      /**
      * Publishing a message
      * @require message
      */
      await nearbyMessagesApi.publish('message');
      /**
      * Subscribing
      */
      await nearbyMessagesApi.backgroundSubscribe();

      // Enable debug mode
      await nearbyMessageAPi.enableDebugMode()
      // Disable debug mode
      await nearbyMessageAPI.disableDebugMode()
    
    Future<void> dispose() async {
      // unPublish
      await nearbyMessagesApi.unPublish();
      // backgroundUnsubscribe
      await nearbyMessagesApi.backgroundUnsubscribe();
    }
}
```
