import 'dart:async';

import 'package:flutter/services.dart';

class FlutterNearbyMessagesApi {
  static const MethodChannel _channel =
      const MethodChannel('flutter_nearby_messages_api');

  FlutterNearbyMessagesApi(Function onFound, Function onLost) {
    _channel.setMethodCallHandler((MethodCall call) async {
      switch (call.method) {
        case 'onFound':
          return onFound(call.arguments);
        case 'onLost':
          return onLost(call.arguments);
        default:
          throw MissingPluginException();
      }
    });
  }

  Future<void> setAPIKey(String key) async {
    await _channel.invokeMethod('setAPIKey', {'apikey': key});
  }

  Future<void> publish(String message) async {
    await _channel.invokeMethod('publish', {'message': message});
  }

  Future<void> setGranted() async {
    await _channel.invokeMethod('setGranted', {'isGranted': true});
  }

  Future<void> unPublish() async {
    await _channel.invokeMethod('unPublish');
  }

  Future<void> backgroundSubscribe() async {
    await _channel.invokeMethod('backgroundSubscribe');
  }

  Future<void> backgroundUnsubscribe() async {
    await _channel.invokeMethod('backgroundUnsubscribe');
  }

  Future<void> enableDebugMode() async {
    await _channel.invokeMethod('enableDebugMode');
  }

  Future<void> disableDebugMode() async {
    await _channel.invokeMethod('disableDebugMode');
  }
}
